@@ -1,5 +1,6 @@
 #include <cstdio>
 #include <cstdlib>
+#include <cstring>
 #include <ctime>
 #include <iostream>
 #include <sstream>
@@ -56,6 +57,7 @@ Options::~Options()
 
 Options::Options() :
     arcSpacing_(0.1),
+    arcThickness_(1),
     background_(""),
     baseMag_(10.0),
     centerSelected_(false),
@@ -82,6 +84,7 @@ Options::Options() :
     labelMask_(XNegative),
     labelX_(-15),
     labelY_(15),
+    labelBody_(UNKNOWN_BODY), 
     labelString_(""), 
     latitude_(0),
     lightTime_(false),
@@ -97,7 +100,6 @@ Options::Options() :
     originFile_(""),
     originID_(0),
     originMode_(LBR),
-    originSet_(false),
     outputBase_(""),
     outputExt_(defaultMapExt),
     outputStartIndex_(0),
@@ -120,7 +122,9 @@ Options::Options() :
     range_(1000),
     rotate_(0),
     rotate0_(0),
-    saveDesktopFile_(false), 
+    saveDesktopFile_(false),
+    separationDist_(0), 
+    separationTarget_(UNKNOWN_BODY), 
     starFreq_(0.001),
     star_map(defaultStarMap),
     sunLat_(0),
@@ -128,7 +132,6 @@ Options::Options() :
     target_(EARTH),
     targetID_(0),
     targetMode_(BODY),
-    targetSet_(false),
     timewarp(1),
     tmpDir_(""),
     transparency_(false),
@@ -146,7 +149,8 @@ Options::Options() :
     windowX_(0),
     windowY_(0),
     windowTitle_(""),
-    xid_(0)
+    xid_(0),
+    XYZFile_("")
 {
     memset(color_, 0, 3);
     color_[0] = 255;          // default label color is red
@@ -189,6 +193,7 @@ Options::parseArgs(int argc, char **argv)
         {
             {"arc_file",       required_argument, NULL, ARC_FILE},
             {"arc_spacing",    required_argument, NULL, ARC_SPACING},
+            {"arc_thickness",  required_argument, NULL, THICKNESS},
             {"background",     required_argument, NULL, BACKGROUND},
             {"base_magnitude", required_argument, NULL, BASEMAG},
             {"body",           required_argument, NULL, TARGET},
@@ -209,10 +214,11 @@ Options::parseArgs(int argc, char **argv)
             {"grs_longitude",  required_argument, NULL, GRS_LON},
             {"hibernate",      required_argument, NULL, HIBERNATE},
             {"idlewait",       required_argument, NULL, IDLEWAIT},
-            {"interpolate_origin_file",          no_argument,       NULL, INTERPOLATE_ORIGIN_FILE},
+            {"interpolate_origin_file", no_argument, NULL, INTERPOLATE_ORIGIN_FILE},
             {"jdate",          required_argument, NULL, JDATE},
             {"label",          no_argument,       NULL, LABEL},
             {"labelpos",       required_argument, NULL, LABELPOS},
+            {"label_body",     required_argument, NULL, LABEL_BODY},
             {"label_string",   required_argument, NULL, LABEL_STRING},
             {"latitude",       required_argument, NULL, LATITUDE},
             {"light_time",     no_argument,       NULL, LIGHT_TIME},
@@ -242,6 +248,7 @@ Options::parseArgs(int argc, char **argv)
             {"rotate",         required_argument, NULL, ROTATE},
             {"save_desktop_file", no_argument,    NULL, SAVE_DESKTOP_FILE},
             {"searchdir",      required_argument, NULL, SEARCHDIR},
+            {"separation",     required_argument, NULL, SEPARATION},
             {"spice_ephemeris", required_argument, NULL, SPICE_EPHEMERIS}, 
             {"spice_file",     required_argument, NULL, SPICE_FILE}, 
             {"starfreq",       required_argument, NULL, STARFREQ},
@@ -262,6 +269,7 @@ Options::parseArgs(int argc, char **argv)
             {"window_title",   required_argument, NULL, WINDOWTITLE},
             {"XID",            required_argument, NULL, XWINID},
             {"xscreensaver",   no_argument,       NULL, VROOT},
+            {"XYZ_file",       required_argument, NULL, XYZFILE},
             {NULL,             0,                 NULL, 0}
         };
 
@@ -396,7 +404,7 @@ Options::parseArgs(int argc, char **argv)
         { 
             double g;
             sscanf(optarg, "%lf", &g);
-            if (g > 0) glare_ = g;
+            if (g >= 0) glare_ = g;
         }
         break;
         case GRS_LON:
@@ -441,6 +449,17 @@ Options::parseArgs(int argc, char **argv)
             drawLabel_ = true;
         }
         break;
+        case LABEL_BODY:
+        {
+            labelBody_ = Planet::parseBodyName(optarg);
+            if (labelBody_ >= UNKNOWN_BODY)
+            {
+                xpWarn("Unknown body specified for label_body\n", 
+                       __FILE__, __LINE__);
+                labelBody_ = UNKNOWN_BODY;
+            }
+        }
+        break;
         case LABEL_STRING:
             labelString_ = optarg;
             drawLabel_ = true;
@@ -498,6 +517,8 @@ Options::parseArgs(int argc, char **argv)
                 north_ = ORBIT;
             else if (strncmp(lowercase, "path", 1) == 0)
                 north_ = PATH;
+            else if (strncmp(lowercase, "separation", 1) == 0)
+                north_ = SEPARATION;
             else if (strncmp(lowercase, "terrestrial", 1) == 0)
                 north_ = TERRESTRIAL;
             else 
@@ -734,6 +755,18 @@ Options::parseArgs(int argc, char **argv)
         case SEARCHDIR:
             searchdir.push_back(optarg);        
             break;
+        case SEPARATION:
+        {
+            const char *colon = strstr(optarg, ":");
+            if (colon != NULL)
+            {
+                sscanf(colon + 1, "%lf", &separationDist_);
+                separationTarget_ = Planet::parseBodyName(optarg);
+                if (separationTarget_ >= RANDOM_BODY) 
+                    separationTarget_ = RANDOM_BODY;
+            }
+        }
+        break;
         case SPICE_EPHEMERIS:
         {
 #ifdef HAVE_CSPICE
@@ -777,7 +810,7 @@ Options::parseArgs(int argc, char **argv)
             switch (target_)
             {
             case ALONG_PATH:
-                targetMode_ = LOOKAT;
+                targetMode_ = XYZ;
                 break;
             case MAJOR_PLANET:
                 targetMode_ = MAJOR;
@@ -793,7 +826,7 @@ Options::parseArgs(int argc, char **argv)
                 else
                 {
                     sscanf(optarg+4, "%d", &targetID_);
-                    targetMode_ = LOOKAT;
+                    targetMode_ = XYZ;
                 }
                 break;
             case NORAD:
@@ -807,7 +840,7 @@ Options::parseArgs(int argc, char **argv)
                 else
                 {
                     sscanf(optarg+5, "%d", &targetID_);
-                    targetMode_ = LOOKAT;
+                    targetMode_ = XYZ;
                 }
                 break;
             case RANDOM_BODY:
@@ -828,6 +861,21 @@ Options::parseArgs(int argc, char **argv)
         case TERRESTRIAL:
             universalTime_ = false;
             break;
+        case THICKNESS:
+        {
+            int thickness;
+            sscanf(optarg, "%d", &thickness);
+            if (thickness > 0)
+            {
+                arcThickness_ = thickness;
+            }
+            else
+            {
+                xpWarn("thickness must be positive.\n", 
+                       __FILE__, __LINE__);
+            }
+        }
+        break;
         case TIMEWARP:
             sscanf(optarg, "%lf", &timewarp);
             useCurrentTime_ = false;
@@ -863,7 +911,6 @@ Options::parseArgs(int argc, char **argv)
             displayMode_ = WINDOW;
             geometrySelected_ = true;
             break;
-        default:
         case XWINID:
         {
             if (optarg[0] == '0'
@@ -878,6 +925,11 @@ Options::parseArgs(int argc, char **argv)
             displayMode_ = WINDOW;
         }
         break;
+        case XYZFILE:
+        {
+            XYZFile_ = optarg;
+        }
+        default:
         case UNKNOWN:
         {
             cout << "Valid options to Xplanet are:\n";
@@ -932,7 +984,7 @@ Options::parseArgs(int argc, char **argv)
 
     // A number of options are meaningless if we're not looking at a
     // planetary body.
-    if (targetMode_ == LOOKAT)
+    if (targetMode_ == XYZ)
     {
         if (projectionMode_ != MULTIPLE)
         {
@@ -988,283 +1040,6 @@ Options::setTarget(const double X, const double Y, const double Z)
     tZ_ = Z;
 }
 
-void
-Options::setOrigin(PlanetProperties *planetProperties[])
-{
-    switch (originMode_)
-    {
-    case LBR:
-    {
-        if (random_)
-        {
-            longitude_ = random() % 360;
-            longitude_ *= deg_to_rad;
-
-            // Weight random latitudes towards the equator
-            latitude_ = (random() % 2000)/1000.0 - 1;
-            latitude_ = asin(latitude_);
-
-            rotate0_ = random() % 360;
-            rotate0_ *= deg_to_rad;
-            rotate_ = rotate0_;
-        }
-        
-        if (origin_ == NAIF || origin_ == NORAD)
-        {
-            findBodyXYZ(julianDay_, origin_, originID_, oX_, oY_, oZ_);
-        }
-        else
-        {
-            if (!targetSet_)
-                xpExit("Target body not set!\n", __FILE__, __LINE__);
-
-            body referenceBody = target_;
-            if (!originFile_.empty()
-                || !dynamicOrigin_.empty()) referenceBody = origin_;
-            
-            Planet p(julianDay_, referenceBody);
-            p.calcHeliocentricEquatorial(); 
-            
-            if (localTime_ >= 0)
-            {
-                double subSolarLat = 0;
-                double subSolarLon = 0;
-                p.XYZToPlanetographic(0, 0, 0, subSolarLat, subSolarLon);
-                
-                longitude_ = (subSolarLon - M_PI
-                              + p.Flipped() * localTime_ * M_PI / 12);
-            }
-            p.PlanetographicToXYZ(oX_, oY_, oZ_,
-                                  latitude_, longitude_, range_);
-        }
-    }
-    break;
-    case MAJOR:
-    case RANDOM:
-    case SYSTEM:
-    {
-        if (!targetSet_)
-            xpExit("Target body not set!\n", __FILE__, __LINE__);
-
-        // check to see that at least one body has random_origin=true
-        bool no_random_origin = true;
-        for (int i = 0; i < RANDOM_BODY; i++)
-        {
-            if (i == target_) continue;
-
-            if (planetProperties[i]->RandomOrigin()) 
-            {
-                no_random_origin = false;
-                break;
-            }
-        }
-
-        if (no_random_origin)
-        {
-            string errMsg("Target is ");
-            errMsg += planetProperties[target_]->Name();
-            errMsg += ", random_origin is false for all other bodies.  ";
-            errMsg += "Check your config file.\n";
-            xpExit(errMsg, __FILE__, __LINE__);
-        }
-
-        bool found_origin = false;
-        while (!found_origin)
-        {
-            origin_ = static_cast<body> (random() % RANDOM_BODY);
-
-            if (verbosity_ > 1)
-            {
-                ostringstream msg;
-                msg << "target = " << body_string[target_] << ", origin = " 
-                    << body_string[origin_] << endl;
-                xpMsg(msg.str(), __FILE__, __LINE__);
-            }
-
-            if (origin_ == target_) continue;
-            
-            if (originMode_ == RANDOM)
-            {
-                found_origin = true;
-            }
-            else
-            {
-                Planet o(julianDay_, origin_);
-                
-                if (originMode_ == MAJOR)
-                {
-                    found_origin = (o.Primary() == SUN);
-                }
-                else if (originMode_ == SYSTEM)
-                {
-                    // SYSTEM means one of three things:
-                    // 1) target and origin have same primary
-                    // 2) target is origin's primary
-                    // 3) origin is target's primary
-                    found_origin = ((primary_ == o.Primary()
-                                     || o.Primary() == target_
-                                     || origin_ == primary_));
-                }
-            }
-
-            if (found_origin) 
-                found_origin = planetProperties[origin_]->RandomOrigin();
-        } // while (!found_origin)
-    }
-    // fall through
-    case BODY:
-    {
-        findBodyXYZ(julianDay_, origin_, originID_, oX_, oY_, oZ_);
-
-        if (oppositeSide_)
-        {
-            oX_ = 2*tX_ - oX_;
-            oY_ = 2*tY_ - oY_;
-            oZ_ = 2*tZ_ - oZ_;
-        }
-    }
-    break;
-    case ABOVE:
-    case BELOW:
-    {
-        if (!targetSet_)
-            xpExit("Target body not set!\n", __FILE__, __LINE__);
-
-        double pX, pY, pZ;
-        findBodyXYZ(julianDay_, primary_, -1, pX, pY, pZ);
-
-        double vX, vY, vZ;
-        findBodyVelocity(julianDay_, target_, targetID_, primary_, -1, 
-                         vX, vY, vZ);
-
-        // cross product of position and velocity vectors points to the
-        // orbital north pole
-        double pos[3] = { tX_ - pX, tY_ - pY, tZ_ - pZ };
-        double vel[3] = { vX, vY, vZ };
-
-        double north[3];
-        cross(pos, vel, north);
-
-        double mag = sqrt(dot(north, north));
-        Planet primary(julianDay_, primary_);
-        double dist = FAR_DISTANCE * primary.Radius();
-        
-        oX_ = dist * north[0]/mag + pX;
-        oY_ = dist * north[1]/mag + pY;
-        oZ_ = dist * north[2]/mag + pZ;
-
-        const double radius = sqrt(pos[0] * pos[0] + pos[1] * pos[1] 
-                                   + pos[2] * pos[2]);
-
-        if (fov_ < 0) // will only be zero if -fov or -radius haven't
-                      // been specified
-        {
-            fov_ = 4*radius/dist; // fit the orbit on the screen
-            fovMode_ = FOV;
-        }
-
-        if (originMode_ == BELOW)
-        {
-            oX_ -= 2 * (oX_ - pX);
-            oY_ -= 2 * (oY_ - pX);
-            oZ_ -= 2 * (oZ_ - pX);
-        }
-    }
-    break;
-    }
-
-    if (rangeSpecified_ && targetMode_ != LOOKAT)
-    {
-        Planet p2(julianDay_, target_);
-        p2.calcHeliocentricEquatorial(); 
-        
-        p2.XYZToPlanetographic(oX_, oY_, oZ_, latitude_, longitude_);
-        p2.PlanetographicToXYZ(oX_, oY_, oZ_, latitude_, longitude_, 
-                               range_);
-    }
-    originSet_ = true;
-}
-
-void
-Options::setTarget(PlanetProperties *planetProperties[])
-{
-    switch (targetMode_)
-    {
-    case MAJOR:
-    case RANDOM:
-    {
-        bool no_random_target = true;
-        for (int i = 0; i < RANDOM_BODY; i++)
-        {
-            if (planetProperties[i]->RandomTarget()) 
-            {
-                no_random_target = false;
-                break;
-            }
-        }
-
-        if (no_random_target)
-        {
-            ostringstream errMsg;
-            errMsg << "random_target is false for all bodies.  "
-                   << "Check your config file.\n";
-            xpExit(errMsg.str(), __FILE__, __LINE__);
-        }
-
-        bool found_target = false;
-        while (!found_target)
-        {
-            target_ = (body) (random() % RANDOM_BODY);
-
-            found_target = planetProperties[target_]->RandomTarget();
-
-            if (found_target && targetMode_ == MAJOR)
-            {
-                Planet p(julianDay_, target_);
-                found_target = (p.Primary() == SUN);
-            }
-        }
-    }
-    // fall through
-    case BODY:
-    {
-        Planet t(julianDay_, target_);
-        primary_ = t.Primary();
-    }
-    break;
-    case LOOKAT:
-        if (target_ == NAIF
-            || target_ == ALONG_PATH)
-        {
-            primary_ = SUN;
-        }
-        else if (target_ == NORAD)
-        {
-            primary_ = EARTH;
-        }
-        break;
-    default:
-        xpExit("Unknown target mode?\n", __FILE__, __LINE__);
-    }
-
-    if (target_ == ALONG_PATH)
-    {
-        findBodyVelocity(julianDay_, origin_, originID_, 
-                         pathRelativeTo_, pathRelativeToID_, 
-                         tX_, tY_, tZ_);
-        
-        tX_ *= FAR_DISTANCE;
-        tY_ *= FAR_DISTANCE;
-        tZ_ *= FAR_DISTANCE;
-    }
-    else
-    {
-        findBodyXYZ(julianDay_, target_, targetID_, tX_, tY_, tZ_);
-    }
-
-    targetSet_ = true;
-}
-
 void
 Options::incrementTime(const double sec)
 {
@@ -1279,15 +1054,3 @@ Options::setTime(const double jd)
     tv_sec = get_tv_sec(julianDay_);
 }
 
-int
-Options::OriginMode() const
-{ 
-    int returnVal = originMode_;
-    
-    if (originMode_ == MAJOR
-        || originMode_ == RANDOM
-        || originMode_ == SYSTEM)
-        returnVal = BODY;
-    
-    return(returnVal);
-}
