@@ -1,15 +1,18 @@
 #include <algorithm>
 #include <cctype>
+#include <cstring>
 #include <string>
 #include <vector>
 using namespace std;
 
 #include "body.h"
+#include "Options.h"
 #include "PlanetProperties.h"
 #include "xpDefines.h"
 
 PlanetProperties::PlanetProperties(const body index)
     : index_(index), 
+      arcThickness_(1),
       bumpMap_(""),
       bumpScale_(1),
       cloudGamma_(1),
@@ -58,12 +61,9 @@ PlanetProperties::PlanetProperties(const body index)
         name_[0] = toupper(name_[0]);
     }
 
-    if (index == EARTH)
-        nightMap_ = "night" + defaultMapExt;
-
-    // Everything besides the name and day and night maps gets set to
-    // default values from the config file in readConfig.cpp, so
-    // there's no point in setting them here.
+    // Everything besides the name and day map gets set to default
+    // values from the config file in readConfig.cpp, so there's no
+    // point in setting them here.
 }
 
 PlanetProperties::~PlanetProperties()
@@ -89,6 +89,8 @@ PlanetProperties::operator= (const PlanetProperties &p)
     for (unsigned int i = 0; i < p.satelliteFiles_.size(); i++)
         satelliteFiles_.push_back(p.satelliteFiles_[i]);
 
+    arcThickness_ = p.arcThickness_;
+
     bumpMap_ = p.bumpMap_;
     bumpScale_ = p.bumpScale_;
 
