@@ -1,6 +1,7 @@
 #include <sys/time.h>
 
 #include <cstdio>
+#include <cstring>
 #include <ctime>
 #include <map>
 #include <sstream>
@@ -72,14 +73,17 @@ drawMultipleBodies(DisplayBase *display, Planet *target,
 
     if (options->Verbosity() > 0)
     {
-        if (options->OriginMode() == BODY 
-            && options->TargetMode() != LOOKAT)
+        if (options->TargetMode() != XYZ
+            && (options->OriginMode() == BODY 
+                || options->OriginMode() == MAJOR
+                || options->OriginMode() == RANDOM
+                || options->OriginMode() == SYSTEM))
         {
             ostringstream msg;
             msg << "Looking at "
-                << planetProperties[options->getTarget()]->Name()
+                << planetProperties[options->Target()]->Name()
                 << " from "
-                << planetProperties[options->getOrigin()]->Name()
+                << planetProperties[options->Origin()]->Name()
                 << endl;
             xpMsg(msg.str(), __FILE__, __LINE__);
 
@@ -105,7 +109,7 @@ drawMultipleBodies(DisplayBase *display, Planet *target,
     case RADIUS:
     {
         double target_pixel_radius = (options->Radius() * height);
-        target_pixel_radius /= planetProperties[options->getTarget()]->Magnify();
+        target_pixel_radius /= planetProperties[options->Target()]->Magnify();
 
         if (target->Index() == SATURN) target_pixel_radius /= 2.32166;
 
@@ -118,7 +122,7 @@ drawMultipleBodies(DisplayBase *display, Planet *target,
     {
         pixels_per_radian = width / options->FieldOfView();
         
-        if (options->TargetMode() != LOOKAT)
+        if (options->TargetMode() != XYZ)
         {
             const double target_angular_radius = target->Radius()/target_dist;
             double target_pixel_radius = (target_angular_radius 
@@ -143,7 +147,28 @@ drawMultipleBodies(DisplayBase *display, Planet *target,
     {
         ostringstream msg;
         char buffer[128];
-        snprintf(buffer, 128, "fov = %14.8f degrees\n", 
+
+        int year, month, day, hour, min;
+        double sec;
+        fromJulian(options->JulianDay(), year, month, day, hour, min, sec);
+
+        snprintf(buffer, 128, "Julian Date = %14.6f (%04d%02d%02d.%02d%02d%02d)\n",
+                 options->JulianDay(), year, month, day, hour, min, (int) (sec+0.5));
+        msg << buffer;
+
+        snprintf(buffer, 128, "origin XYZ  = %14.8f %14.8f %14.8f\n",
+                 oX, oY, oZ);
+        msg << buffer;
+
+        snprintf(buffer, 128, "target XYZ  = %14.8f %14.8f %14.8f\n",
+                 tX, tY, tZ);
+        msg << buffer;
+
+        snprintf(buffer, 128, "up XYZ      = %14.8f %14.8f %14.8f\n",
+                 upX, upY, upZ);
+        msg << buffer;
+
+        snprintf(buffer, 128, "fov         = %14.8f degrees\n", 
                  options->FieldOfView()/deg_to_rad);
         msg << buffer;
         snprintf(buffer, 128, "dist_per_pixel = %14.8f\n", dist_per_pixel);
@@ -156,8 +181,7 @@ drawMultipleBodies(DisplayBase *display, Planet *target,
     if (options->OriginMode() == ABOVE
         || options->OriginMode() == BELOW)
     {
-        findBodyXYZ(options->JulianDay(), options->getPrimary(), 
-                    -1, tX, tY, tZ);
+        findBodyXYZ(options->JulianDay(), options->Primary(), -1, tX, tY, tZ);
     }
 
     View *view = new View(oX, oY, oZ, tX, tY, tZ, 
@@ -378,6 +402,7 @@ drawMultipleBodies(DisplayBase *display, Planet *target,
                             ring_brightness, LIT, ring_transparency, 
                             TRANSP, sLon, sLat,
                             currentProperties->Shade(), 
+                            planetsFromSunMap, 
                             current_planet);
 
             const bool lit_side = (sLat * oLat > 0);
