@@ -1,3 +1,4 @@
+#include <cstring>
 #include <map>
 #include <vector>
 using namespace std;
@@ -64,6 +65,7 @@ drawProjection(DisplayBase *display, Planet *target,
                         ring_brightness, LIT, ring_transparency, TRANSP,
                         sLon, sLat, 
                         planetProperties->Shade(), 
+                        planetsFromSunMap, 
                         target);
     }
 
@@ -116,14 +118,57 @@ drawProjection(DisplayBase *display, Planet *target,
                 annotationMap);
 
     if (planetProperties->DrawMarkers())
-        addMarkers(planetProperties, target, 0, 0, 0, 0, 
-                   NULL, projection, width, height, 
+        addMarkers(planetProperties, target, projection->Radius() * height,
+                   0, 0, 0, NULL, projection, width, height, 
                    planetsFromSunMap, annotationMap);
 
     if (planetProperties->DrawSatellites())
         addSatellites(planetProperties, target, NULL, projection,
                       annotationMap);
 
+    // add tabs to make a photocube.  Lines are black, so -background
+    // white will make them stand out.
+    if (options->Projection() == TSC)
+    {
+        unsigned char black[3] = { 0, 0, 0 };
+        const int thickness = 3;
+        const double Z = 0;
+        LineSegment *ls = NULL;
+
+        int blockWidth = width/4;
+        for (int i = 0; i < 4; i++)
+        {
+            if (i == 1) continue;
+
+            double X0 = i * blockWidth;
+
+            ls = new LineSegment(black, thickness, X0, height/3, 
+                                 X0+width/40, 9*height/30);
+            annotationMap.insert(pair<const double, Annotation*>(Z, ls));
+
+            ls = new LineSegment(black, thickness, X0+width/4, height/3, 
+                                 X0+9*width/40, 9*height/30);
+            annotationMap.insert(pair<const double, Annotation*>(Z, ls));
+
+            ls = new LineSegment(black, thickness, X0+width/40, 9*height/30, 
+                                 X0+9*width/40, 9*height/30);
+            annotationMap.insert(pair<const double, Annotation*>(Z, ls));
+
+            ls = new LineSegment(black, thickness, X0, 2*height/3, 
+                                 X0+width/40, 21*height/30);
+            annotationMap.insert(pair<const double, Annotation*>(Z, ls));
+
+            ls = new LineSegment(black, thickness, X0+width/4, 2*height/3, 
+                                 X0+9*width/40, 21*height/30);
+            annotationMap.insert(pair<const double, Annotation*>(Z, ls));
+
+            ls = new LineSegment(black, thickness, X0+width/40, 21*height/30, 
+                                 X0+9*width/40, 21*height/30);
+            annotationMap.insert(pair<const double, Annotation*>(Z, ls));
+        }
+
+    }
+
     const bool limbDarkening = (options->Projection() == HEMISPHERE
                                 || options->Projection() == ORTHOGRAPHIC);
 
